#!/bin/bash
#
# buildRoot.sh <gcc46|e1|mu2e|nova> [opt|debug|prof]

basequal=${1}
extraqual=${2}
pkgver=v5_32_01
pkgdotver=v5.32.01

# check to see if qualifier is set
if [ -z ${basequal} ]
then
   echo "ERROR: please define the qualifier"
   echo "USAGE: buildRoot.sh <gcc46|mu2e|nova> [opt|debug|prof]"
   exit 1
fi

if [ "${basequal}" = "gcc46" ] 
then
    gcctestver=4.6
    shortqual=gcc
elif [ "${basequal}" = "e1" ] 
then
    gcctestver=4.6
    shortqual=e
elif [ "${basequal}" = "nova" ] 
then
    gcctestver=4.6
    shortqual=nova
elif [ "${basequal}" = "mu2e" ] 
then
    gcctestver=4.6
    shortqual=mu2e
else
   echo "ERROR: unrecognized qualifier"
   echo "USAGE: buildRoot.sh <gcc46|nova|mu2e> [opt|debug|prof]"
   exit 1
fi

# use ROOTSYS/MyRules.mk
if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    rules=MyRules_opt.mk
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extracommand="--build=debug"
    rules=MyRules_debug.mk
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    rules=MyRules_prof.mk
else
    # default CXXFLAGS are -g -O2
    fullqual=${basequal}
    qualdir=${basequal}
    extracommand="--build=debug"
fi

echo "compiling for ${fullqual}"

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
rootdir=${PRODUCTS}/root/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/root/${pkgver}/source

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# declare now so we can setup
mkdir -p ${rootdir}
if [ ! -d ${rootdir} ]
then
   echo "ERROR: failed to create ${rootdir}"
   exit 1
fi

echo "Declaring root ${pkgver} ${flvr} -q ${fullqual}"
if [ ${OS} = "Darwin" ]
then
   ups declare root ${pkgver} -r root/${pkgver} -2 -m root.table -q ${fullqual}
else 
   ups declare root ${pkgver} -r root/${pkgver} -4 -m root.table -q ${fullqual}
fi

# setup root
setup root ${pkgver} -q ${fullqual}
gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ "${gccver}" = "${gcctestver}" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ -z ${FFTW_INC} ]
then
   echo "ERROR: failed to setup fftw"
   exit 1
else
   echo "FFTW_INC: ${FFTW_INC}"
fi

if [ -z ${LIBXML2_INC} ]
then
   echo "ERROR: failed to setup libxml"
   exit 1
else
   echo "LIBXML2_INC: ${LIBXML2_INC}"
fi

if [ "${shortqual}" = "nova" ] 
then
    if [ -z ${POSTGRESQL_VERSION} ]
    then
       echo "ERROR: failed to setup postgresql"
       exit 1
    else
       echo "postgresql version: ${POSTGRESQL_VERSION}"
    fi

    if [ -z ${MYSQL_CLIENT_VERSION} ]
    then
       echo "ERROR: failed to setup mysql_client"
       exit 1
    else
       echo "mysql_client version: ${MYSQL_CLIENT_VERSION}"
    fi
fi

if [ -z ${PYTHONHOME} ]
then
   echo "ERROR: PYTHONHOME is undefined"
   echo "       something is very wrong"
   exit 1
fi

cd ${rootdir}
tar xzf ${sourcedir}/root_v5.32.01.source.tar.gz

# get the extra rules 
if [ -n ${rules} ]
then
   cp ${ROOT_DIR}/${rules} ${rootdir}/root/MyRules.mk
fi
if [ "${basequal}" = "e1" ] 
then
  echo "CXXFLAGS += -std=c++0x -Wno-deprecated-declarations" >> ${rootdir}/root/MyRules.mk
  echo "NOOPT += -std=c++0x -Wno-deprecated-declarations" >> ${rootdir}/root/MyRules.mk
fi

set -x

cd ${rootdir}/root

# apply Fermi patches
patch -b -p0 < ${sourcedir}/fermi_root_5_32_00_slf5_32bit.patch

if [ "${shortqual}" = "nova" ]
then
./configure ${extracommand} \
--prefix=${ROOTSYS} \
--etcdir=${ROOTSYS}/etc \
--enable-gdml \
--with-fftw3-incdir=${FFTW_INC} \
--with-fftw3-libdir=${FFTW_FQ_DIR}/lib/ \
--disable-xrootd \
--enable-minuit2 \
--disable-xft \
--with-python-incdir=${PYTHON_INCLUDE} \
--with-python-libdir=${PYTHON_LIB} \
--with-xml-incdir=${LIBXML2_INC} \
--with-xml-libdir=${LIBXML2_FQ_DIR}/lib \
--with-pythia6-libdir=${PYLIB} \
--with-pgsql-incdir=${POSTGRESQL_FQ_DIR}/include \
--with-pgsql-libdir=${POSTGRESQL_FQ_DIR}/lib \
--with-mysql-incdir=${MYSQL_CLIENT_FQ_DIR}/include/mysql \
--with-mysql-libdir=${MYSQL_CLIENT_FQ_DIR}/lib/mysql
elif [ "${shortqual}" = "mu2e" ]
then
./configure ${extracommand} \
--prefix=${ROOTSYS} \
--etcdir=${ROOTSYS}/etc \
--enable-gdml \
--enable-roofit \
--with-fftw3-incdir=${FFTW_INC} \
--with-fftw3-libdir=${FFTW_FQ_DIR}/lib/ \
--disable-mysql \
--disable-xrootd \
--enable-minuit2 \
--disable-xft \
--with-python-incdir=${PYTHON_INCLUDE} \
--with-python-libdir=${PYTHON_LIB} \
--with-xml-incdir=${LIBXML2_INC} \
--with-xml-libdir=${LIBXML2_FQ_DIR}/lib
else
./configure ${extracommand} \
--prefix=${ROOTSYS} \
--etcdir=${ROOTSYS}/etc \
--enable-gdml \
--with-fftw3-incdir=${FFTW_INC} \
--with-fftw3-libdir=${FFTW_FQ_DIR}/lib/ \
--disable-mysql \
--disable-xrootd \
--enable-minuit2 \
--disable-xft \
--with-python-incdir=${PYTHON_INCLUDE} \
--with-python-libdir=${PYTHON_LIB} \
--with-xml-incdir=${LIBXML2_INC} \
--with-xml-libdir=${LIBXML2_FQ_DIR}/lib
fi

make -j3
# now install in ROOTSYS
make install 

set +x

if [ ! -d ${rootdir}/lib ]
then
   echo "ERROR: failed to create ${rootdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building root ${pkgver} ${flvr} -q ${fullqual}"
setup root ${pkgver} -q ${fullqual}
echo "root is installed at ${ROOTSYS}"

exit 0
